@@ -34,10 +34,12 @@ from blog import Blog
 from page import Page
 from country import Country
 from fulfillment import Fulfillment
+from fulfillment_service import FulfillmentService
 from transaction import Transaction
 from image import Image
 from variant import Variant
 from order import Order
+from order_risk import OrderRisk
 from smart_collection import SmartCollection
 
 from ..base import ShopifyResource
