@@ -1,5 +1,7 @@
 from ..base import ShopifyResource
 from shopify import mixins
+from comment import Comment
+
 
 class Article(ShopifyResource, mixins.Metafields, mixins.Events):
     _prefix_source = "/admin/blogs/$blog_id/"
@@ -10,7 +12,7 @@ class Article(ShopifyResource, mixins.Metafields, mixins.Events):
         if blog_id:
             return "/admin/blogs/%s" % (blog_id)
         else:
-            return "/admin/"
+            return "/admin"
 
     def comments(self):
         return Comment.find(article_id=self.id)
