@@ -1,11 +1,13 @@
 from ..base import ShopifyResource
 from shopify import mixins
 from collect import Collect
+import product
+
 
 class CustomCollection(ShopifyResource, mixins.Metafields, mixins.Events):
 
     def products(self):
-        return Product.find(collection_id=self.id)
+        return product.Product.find(collection_id=self.id)
 
     def add_product(self, product):
         return Collect.create({'collection_id': self.id, 'product_id': product.id})
