@@ -1,5 +1,8 @@
 from ..base import ShopifyResource
 from shopify import mixins
+from custom_collection import CustomCollection
+from smart_collection import SmartCollection
+
 
 class Product(ShopifyResource, mixins.Metafields, mixins.Events):
 
