@@ -1,6 +1,7 @@
 from ..base import ShopifyResource
 from shopify import mixins
 
+
 class Variant(ShopifyResource, mixins.Metafields):
     _prefix_source = "/admin/products/$product_id/"
 
@@ -10,4 +11,4 @@ class Variant(ShopifyResource, mixins.Metafields):
         if product_id:
             return "/admin/products/%s" % (product_id)
         else:
-            return "/admin/"
+            return "/admin"
